# Horus Media Server Client

An [Horus Media Server](https://horus.nu/horus-geo-suite/) client python library

## Install latest

Install the latest package using pip.

```
pip install horus-media-client
```

## Run example strategy tool

```
python -m horus_media_examples.example_strategy --help
```
